@@ -1,6 +1,6 @@
 package SPVM;
 
-our $VERSION = '0.9510';
+our $VERSION = '0.9511';
 
 use 5.008007;
 use strict;
@@ -58,7 +58,10 @@ sub import {
       $BUILDER->print_error_messages(*STDERR);
       exit(255);
     }
-    
+
+    # Build runtime information
+    $BUILDER->build_runtime;
+
     # Class names added at this compilation
     my $added_class_names = [];
     my $class_names = $BUILDER->get_class_names;
@@ -70,9 +73,6 @@ sub import {
     # Bind SPVM method to Perl
     bind_to_perl($BUILDER, $added_class_names);
 
-    # Build runtime information
-    $BUILDER->build_runtime;
-    
     # Set addresses of native methods and precompile methods
     for my $added_class_name (@$added_class_names) {
       next if $added_class_name =~ /::anon/;
@@ -517,10 +517,18 @@ SPVM build directory for precompile and native method.
 
 If SPVM_BUILD_DIR environment variable is not set, SPVM can't compile precompile method and native method, and a exception occur. You see error message "SPVM_BUILD_DIR environment variable must be set ...".
 
+B<bash:>
+
 In bash, you can set SPVM_BUILD_DIR to the following.
 
   export SPVM_BUILD_DIR=~/.spvm_build
 
+B<csh:>
+
+In csh, you can set SPVM_BUILD_DIR to the following.
+
+  setenv SPVM_BUILD_DIR ~/.spvm_build
+
 =head2 SPVM_CC_DEBUG
 
 Print L<SVPM::Builder::CC> compile and link outputs to stderr.
