@@ -75,6 +75,28 @@ sub is_resource {
   }
 }
 
+sub is_lib_file {
+  my $self = shift;
+  if (@_) {
+    $self->{is_lib_file} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{is_lib_file};
+  }
+}
+
+sub is_native_source {
+  my $self = shift;
+  if (@_) {
+    $self->{is_native_source} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{is_native_source};
+  }
+}
+
 sub is_exe_config {
   my $self = shift;
   if (@_) {
@@ -101,6 +123,10 @@ sub new {
 
   bless $self, $class;
   
+  unless (defined $self->ccflags) {
+    $self->ccflags([]);
+  }
+  
   return $self;
 }
 
@@ -120,50 +146,64 @@ Fields of B<SPVM::Builder::ObjectFileInfo>.
 
 =head2 object_file
 
-  my $object_file = $object_file->object_file;
-  $object_file->object_file($object_file);
+  my $object_file = $object_file_info->object_file;
+  $object_file_info->object_file($object_file);
 
 Get and set the object file that is compiled.
 
 =head2 source_file
 
-  my $source_file = $object_file->source_file;
-  $object_file->source_file($source_file);
+  my $source_file = $object_file_info->source_file;
+  $object_file_info->source_file($source_file);
 
 Get and set the source file that is the source of the compiled object file.
 
 =head2 cc
 
-  my $cc = $object_file->cc;
-  $object_file->cc($cc);
+  my $cc = $object_file_info->cc;
+  $object_file_info->cc($cc);
 
 Get and set the compiler name that compiled the object file.
 
 =head2 ccflags
 
-  my $ccflags = $object_file->ccflags;
-  $object_file->ccflags($ccflags);
+  my $ccflags = $object_file_info->ccflags;
+  $object_file_info->ccflags($ccflags);
 
-Get and set the compiler flags that compiled the object file.
+Get and set the compiler flags that compiled the object file. The default value is C<[]>.
 
 =head2 class_name
 
-  my $class_name = $object_file->class_name;
-  $object_file->class_name($class_name);
+  my $class_name = $object_file_info->class_name;
+  $object_file_info->class_name($class_name);
 
 Get and set the class name belonged to when the object file was compiled.
 
 =head2 is_resource
 
-  my $is_resource = $object_file->is_resource;
-  $object_file->is_resource($is_resource);
+  my $is_resource = $object_file_info->is_resource;
+  $object_file_info->is_resource($is_resource);
 
 Get and set if the object file(this is static library(.a)) is a resource.
 
+=head2 is_lib_file
+
+  my $is_lib_file = $object_file_info->is_lib_file;
+  $object_file_info->is_lib_file($is_lib_file);
+
+Get and set if the object file is a library file.
+
+=head2 is_native_source
+
+  my $is_native_source = $object_file_info->is_native_source;
+  $object_file_info->is_native_source($is_native_source);
+
+Get and set if the object file is compiled from a native source file.
+
 =head2 is_exe_config
 
-  my $is_exe_config = $object_file->is_exe_config;
-  $object_file->is_exe_config($is_exe_config);
+  my $is_exe_config = $object_file_info->is_exe_config;
+  $object_file_info->is_exe_config($is_exe_config);
 
 Get and set if the object file is compiled using L<SPVM::Builder::Config::Exe>.
 
@@ -173,13 +213,13 @@ Methods of B<SPVM::Builder::ObjectFileInfo>.
 
 =head2 new
 
-  my $object_file = SPVM::Builder::ObjectFileInfo->new;
+  my $object_file_info = SPVM::Builder::ObjectFileInfo->new;
 
 =head2 to_string
 
-  my $object_file_name = $object_file->to_string;
+  my $object_file = $object_file_info->to_string;
 
-Get object file name. This is same as C<object_file> field.
+Get the object file name. This is same as C<object_file> field.
 
 =head1 OPERATORS
 
@@ -187,12 +227,12 @@ L<SPVM::BlessedObject::String> overloads the following operators.
 
 =head2 bool
 
-  my $bool = !!$object_file;
+  my $bool = !!$object_file_info;
   
 Always true.
 
 =head2 stringify
 
-  my $object_file_name = "$object_file";
+  my $object_file_name = "$object_file_info";
   
 Alias for L</"to_string">.
