@@ -269,22 +269,22 @@ enum {
   SPVM_OPCODE_C_ID_IF_EXCEPTION_RETURN,
   SPVM_OPCODE_C_ID_LOOKUP_SWITCH,
   SPVM_OPCODE_C_ID_CASE_INFO,
-  SPVM_OPCODE_C_ID_ARRAY_FETCH_BYTE,
-  SPVM_OPCODE_C_ID_ARRAY_FETCH_SHORT,
-  SPVM_OPCODE_C_ID_ARRAY_FETCH_INT,
-  SPVM_OPCODE_C_ID_ARRAY_FETCH_LONG,
-  SPVM_OPCODE_C_ID_ARRAY_FETCH_FLOAT,
-  SPVM_OPCODE_C_ID_ARRAY_FETCH_DOUBLE,
-  SPVM_OPCODE_C_ID_ARRAY_FETCH_OBJECT,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_BYTE,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_SHORT,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_INT,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_LONG,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_FLOAT,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_DOUBLE,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_OBJECT,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_OBJECT_CHECK_TYPE,
-  SPVM_OPCODE_C_ID_ARRAY_STORE_UNDEF,
+  SPVM_OPCODE_C_ID_GET_ARRAY_ELEMENT_BYTE,
+  SPVM_OPCODE_C_ID_GET_ARRAY_ELEMENT_SHORT,
+  SPVM_OPCODE_C_ID_GET_ARRAY_ELEMENT_INT,
+  SPVM_OPCODE_C_ID_GET_ARRAY_ELEMENT_LONG,
+  SPVM_OPCODE_C_ID_GET_ARRAY_ELEMENT_FLOAT,
+  SPVM_OPCODE_C_ID_GET_ARRAY_ELEMENT_DOUBLE,
+  SPVM_OPCODE_C_ID_GET_ARRAY_ELEMENT_OBJECT,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_BYTE,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_SHORT,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_INT,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_LONG,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_FLOAT,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_DOUBLE,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_OBJECT,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_OBJECT_CHECK_TYPE,
+  SPVM_OPCODE_C_ID_SET_ARRAY_ELEMENT_UNDEF,
   SPVM_OPCODE_C_ID_ARRAY_LENGTH,
   SPVM_OPCODE_C_ID_NEW_OBJECT,
   SPVM_OPCODE_C_ID_NEW_OBJECT_ARRAY,
