@@ -10,6 +10,8 @@ This document describes L<the usage of SPVM Native APIs|/"List-of-Native-APIs">,
 
 Native methods can be written by C language or C++. If the rule of the function call is same as C, you can use any language, for example, CUDA/nvcc.
 
+B<The interfaces and IDs of Native APIs that is added after 0.9506+(after 181+) will be changed many times.>
+
 =head1 Native Methods
 
 =head2 Native Method Declarations
@@ -639,7 +641,7 @@ Native APIs of L<SPVM> have the IDs that is corresponding to the names. These ID
   12 long_object_basic_type_id
   13 float_object_basic_type_id
   14 double_object_basic_type_id
-  15 compiler
+  15 runtime
   16 exception_object
   17 native_mortal_stack
   18 native_mortal_stack_top
@@ -810,35 +812,7 @@ Native APIs of L<SPVM> have the IDs that is corresponding to the names. These ID
   183 init_env,
   184 call_init_blocks,
   185 cleanup_global_vars,
-  186 new_compiler,
-  187 compiler_free,
-  188 compiler_set_start_line,
-  189 compiler_get_start_line,
-  190 compiler_set_start_file,
-  191 compiler_get_start_file,
-  192 compiler_add_module_dir,
-  193 compiler_get_module_dirs_length,
-  194 compiler_get_module_dir,
-  195 compiler_compile_spvm,
-  196 compiler_get_error_messages_length,
-  197 compiler_get_error_message,
-  198 compiler_get_class_id,
-  199 compiler_get_classes_length,
-  200 compiler_get_class_name,
-  201 compiler_is_anon_class,
-  202 compiler_get_methods_length,
-  203 compiler_get_method_id,
-  204 compiler_get_method_id_by_name,
-  205 compiler_get_method_name,
-  206 compiler_get_method_signature,
-  207 compiler_is_anon_method,
-  208 compiler_is_init_block_method,
-  209 compiler_is_native_method,
-  210 compiler_is_precompile_method,
-  211 compiler_get_native_method_address,
-  212 compiler_get_precompile_method_address,
-  213 compiler_set_native_method_address,
-  214 compiler_set_precompile_method_address,
+  186 is_object_array,
 
 =head1 List of Native APIs
 
@@ -886,6 +860,8 @@ Offset of type dimension in object structure. This is used internally.
 
 Offset of runtime type category in object structure. This is used internally.
 
+This value is always C<NULL>, because SPVM 0.9511+, this value is any more used.
+
 =head2 object_flag_offset
 
   void* object_flag_offset;
@@ -934,11 +910,11 @@ ID of the base type of L<Float|SPVM::Float> type. This is used internally.
 
 ID of the base type of L<Double|SPVM::Double> type. This is used internally.
 
-=head2 compiler
+=head2 runtime
 
-  void* compiler;
+  void* runtime;
 
-A pointer to the SPVM compiler. This is used internally.
+A pointer to the runtime information. This is used internally.
 
 =head2 exception_object
 
@@ -1901,7 +1877,7 @@ Free an environment that is created by the L<"new_env"> native API.
 
   void* memory_blocks_count;
 
-Memory blocks count. This is used internally.
+Unused from v0.9508+. The count of memory blocks is managed in L<"runtime">.
 
 =head2 get_chars
 
@@ -2513,24 +2489,32 @@ If the string is read-only, returns C<1>, otherwise returns C<0>.
 
 If the object is an array, returns C<1>, otherwise returns C<0>.
 
+If the object is C<NULL>, returns C<0>.
+
 =head2 is_string
 
   int32_t (*is_string)(SPVM_ENV* env, void* object);
 
 If the object is a string, returns C<1>, otherwise returns C<0>.
 
+If the object is C<NULL>, returns C<0>.
+
 =head2 is_numeric_array
 
   int32_t (*is_numeric_array)(SPVM_ENV* env, void* object);
 
 If the object is a numeric array, returns C<1>, otherwise returns C<0>.
 
+If the object is C<NULL>, returns C<0>.
+
 =head2 is_mulnum_array
 
   int32_t (*is_mulnum_array)(SPVM_ENV* env, void* object);
 
 If the object is a multi numeric array, returns C<1>, otherwise returns C<0>.
 
+If the object is C<NULL>, returns C<0>.
+
 =head2 get_elem_byte_size
 
   int32_t (*get_elem_byte_size)(SPVM_ENV* env, void* array);
@@ -2623,7 +2607,7 @@ If the string is C<NULL>, nothing is printed.
 
 =head2 new_env_raw
 
-  SPVM_ENV* (*new_env_raw)(SPVM_ENV* env);
+  SPVM_ENV* (*new_env_raw)();
 
 Create a new environment. This environment is not yet initialized.
 
@@ -2651,185 +2635,33 @@ Call C<INIT> blocks.
 
 Cleanup gloval variable, such as class variables and the exception variable.
 
-=head2 new_compiler
-  
-  void* (*new_compiler)(SPVM_ENV* env);
+=head2 is_object_array
 
-New a compiler.
+  int32_t (*is_object_array)(SPVM_ENV* env, void* object);
 
-=head2 compiler_free
-  
-  void (*compiler_free)(SPVM_ENV* env, void* compiler);
+If the object is a object array, returns C<1>, otherwise returns C<0>.
 
-Free a compiler.
+If the object is C<NULL>, returns C<0>.
 
-=head2 compiler_set_start_line
-  
-  void (*compiler_set_start_line)(SPVM_ENV* env, void* compiler, int32_t start_line);
+=head1 Compiler Native API
 
-Set the start line of the compiler.
+L<SPVM::Document::NativeAPI::Compiler>
 
-=head2 compiler_get_start_line
-  
-  int32_t (*compiler_get_start_line)(SPVM_ENV* env, void* compiler);
+=head1 Precompile Native API
 
-Get the start line of the compiler.
+L<SPVM::Document::NativeAPI::Precompile>
 
-=head2 compiler_set_start_file
-  
-  void (*compiler_set_start_file)(SPVM_ENV* env, void* compiler, const char* start_file);
+=head1 Runtime Native API
 
-Set the start file of the compiler.
+L<SPVM::Document::NativeAPI::Runtime>
 
-=head2 compiler_get_start_file
-  
-  const char* (*compiler_get_start_file)(SPVM_ENV* env, void* compiler);
+=head1 String Buffer Native API
 
-Get the start file of the compiler.
+L<SPVM::Document::NativeAPI::StringBuffer>
 
-=head2 compiler_add_module_dir
-  
-  void (*compiler_add_module_dir)(SPVM_ENV* env, void* compiler, const char* module_dir);
+=head1 Allocator Native API
 
-Add a module searching directory of the compiler.
-
-=head2 compiler_get_module_dirs_length
-  
-  int32_t (*compiler_get_module_dirs_length)(SPVM_ENV* env, void* compiler);
-
-Get the length of the module searching directories of the compiler.
-
-=head2 compiler_get_module_dir
-
-  const char* (*compiler_get_module_dir)(SPVM_ENV* env, void* compiler, int32_t module_dir_id);
-
-Get a searching directories of the compiler with the index.
-
-=head2 compiler_compile_spvm
-  
-  int32_t (*compiler_compile_spvm)(SPVM_ENV* env, void* compiler, const char* class_name);
-
-Compile the SPVM class.
-
-=head2 compiler_get_error_messages_length
-  
-  int32_t (*compiler_get_error_messages_length)(SPVM_ENV* env, void* compiler);
-
-Get the length of the compiler error messages.
-
-=head2 compiler_get_error_message
-  
-  const char* (*compiler_get_error_message)(SPVM_ENV* env, void* compiler, int32_t index);
-
-Get a compiler error messages with the index.
-
-=head2 compiler_get_class_id
-  
-  int32_t (*compiler_get_class_id)(SPVM_ENV* env, void* compiler, const char* class_name);
-
-Get class ID with the class name.
-
-If the class doesn't found, return a negative value.
-
-=head2 compiler_get_classes_length
-  
-  int32_t (*compiler_get_classes_length)(SPVM_ENV* env, void* compiler);
-
-Get the length of classes that is compiled by the compiler.
-
-=head2 compiler_get_class_name
-  
-  const char* (*compiler_get_class_name)(SPVM_ENV* env, void* compiler, int32_t class_id);
-
-Get the class name with the class id.
-
-=head2 compiler_is_anon_class
-  
-  int32_t (*compiler_is_anon_class)(SPVM_ENV* env, void* compiler, int32_t class_id);
-
-If the class is an anon class, return C<1>, otherwise return C<0>.
-
-=head2 compiler_get_methods_length
-  
-  int32_t (*compiler_get_methods_length)(SPVM_ENV* env, void* compiler, int32_t class_id);
-
-Get the length of methods of the class.
-
-=head2 compiler_get_method_id
-  
-  int32_t (*compiler_get_method_id)(SPVM_ENV* env, void* compiler, int32_t class_id, int32_t method_index_of_class);
-
-Get the method id with the class id and the method index of the class.
-
-If the method doesn't found, return a negative value.
-
-=head2 compiler_get_method_id_by_name
-  
-  int32_t (*compiler_get_method_id_by_name)(SPVM_ENV* env, void* compiler, const char* class_name, const char* method_name);
-
-Get the method id with the class name and the method name.
-
-If the method doesn't found, return a negative value.
-
-=head2 compiler_get_method_name
-  
-  const char* (*compiler_get_method_name)(SPVM_ENV* env, void* compiler, int32_t method_id);
-
-Get the method name with the method ID.
-
-=head2 compiler_get_method_signature
-  
-  const char* (*compiler_get_method_signature)(SPVM_ENV* env, void* compiler, int32_t method_id);
-
-Get the method signature with the method ID.
-
-=head2 compiler_is_anon_method
-  
-  int32_t (*compiler_is_anon_method)(SPVM_ENV* env, void* compiler, int32_t method_id);
-
-Get the method name with the method ID.
-
-=head2 compiler_is_init_block_method
-  
-  int32_t (*compiler_is_init_block_method)(SPVM_ENV* env, void* compiler, int32_t method_id);
-
-If the method is the method of C<INIT> block, return C<1>, otherwise return C<0>.
-
-=head2 compiler_is_native_method
-  
-  int32_t (*compiler_is_native_method)(SPVM_ENV* env, void* compiler, int32_t method_id);
-
-If the method is a native method, return C<1>, otherwise return C<0>.
-
-=head2 compiler_is_precompile_method
-  
-  int32_t (*compiler_is_precompile_method)(SPVM_ENV* env, void* compiler, int32_t method_id);
-
-If the method is a precompile method, return C<1>, otherwise return C<0>.
-
-=head2 compiler_get_native_method_address
-  
-  void* (*compiler_get_native_method_address)(SPVM_ENV* env, void* compiler, int32_t method_id);
-
-Get the native method address.
-
-=head2 compiler_get_precompile_method_address
-  
-  void* (*compiler_get_precompile_method_address)(SPVM_ENV* env, void* compiler, int32_t method_id);
-
-Get the precompile method address.
-
-=head2 compiler_set_native_method_address
-  
-  void (*compiler_set_native_method_address)(SPVM_ENV* env, void* compiler, int32_t method_id, void* address);
-
-Set the native method address.
-
-=head2 compiler_set_precompile_method_address
-  
-  void (*compiler_set_precompile_method_address)(SPVM_ENV* env, void* compiler, int32_t method_id, void* address);
-
-Set the precompile method address.
+L<SPVM::Document::NativeAPI::Allocator>
 
 =head1 Utilities
 
