@@ -4,7 +4,7 @@ package SPVM::EqualityChecker;
 
 =head1 NAME
 
-SPVM::EqualityChecker - EqualityChecker in SPVM | a callback interface to check the object equality
+SPVM::EqualityChecker - A Callback Type to Check the Object Equality
 
 =head1 SYNOPSYS
   
@@ -29,12 +29,10 @@ SPVM::EqualityChecker - EqualityChecker in SPVM | a callback interface to check
 
 =head1 DESCRIPTION
 
-L<EqualityChecker|SPVM::EqualityChecker> is a callback interface to check the object equality.
+L<EqualityChecker|SPVM::EqualityChecker> is a callback type to check the object equality.
 
-=head1 CALLBACK METHOD INTERFACE
+=head1 CALLBACK METHOD
 
   method : int ($object1 : object, $object2 : object)
 
-If the two objects are equals, return 1, otherwise return 0.
-
-This method is planned to be implemented in other classes.
+The implementation must receive two objects and if they are equals, return C<1>, otherwise return C<0>.
