@@ -192,7 +192,7 @@ SPVM::Fn - SPVM Starndard Functions
   $minimals->[2] = TestCase::Minimal->new;
   $minimals->[2]{x} = 2;
   $minimals->[2]{y} = 9;
-  Fn->sort_object$minimals, 0, scalar @$minimals, method : int ($object1 : object, $object2 : object) {
+  Fn->sort_object($minimals, 0, scalar @$minimals, method : int ($object1 : object, $object2 : object) {
     my $minimal1 = (TestCase::Minimal)$object1;
     my $minimal2 = (TestCase::Minimal)$object2;
     
@@ -452,7 +452,7 @@ Offset + length must not be in the array range, othrewise an exception occurs.
 
 =head2 copy_array_range_object
 
-  static method copy_array_range_object : oarray ($elems : oarray, $offset : int, $length : int)
+  static method copy_array_range_object : object[] ($elems : object[], $offset : int, $length : int)
 
 Slice elements in the object array with the start offset and the length.
 
@@ -574,7 +574,7 @@ If byte array is undef, return undef.
 
 =head2 dump_array_object
 
-  static method dump_array_object : string ($objects : oarray, $stringer : Stringer)
+  static method dump_array_object : string ($objects : object[], $stringer : Stringer)
   
 Convert the elements in the object array to string by a C<SPVM::Stringer> callback implementation and join them with "," and surround it with "[" and "]", and return it.
 
@@ -680,7 +680,7 @@ If at least one of the arrays is undef, a excetpion occurs.
 
 =head2 equals_array_object
 
-  static method static method equals_array_object : int ($objs1 : oarray, $objs2 : oarray, $equality_checker : EqualityChecker)
+  static method static method equals_array_object : int ($objs1 : object[], $objs2 : object[], $equality_checker : EqualityChecker)
 
 Check equality of two objects. You must sepecify a L<EqualityChecker|SPVM::EqualityChecker> object to check the equality of each element.
 
@@ -813,6 +813,30 @@ If character is uppercase letter('A'-'Z'), return 1. If not, return 0.
 
 If character is hexadecimal digit('0'-'9', 'A'-'F', 'a'-'f'), return 1. If not, return 0.
 
+=head2 is_mulnum_array
+
+  static method is_mulnum_array : int ($object : object)
+
+If the object is a multi numeric array, returns C<1>, otherwise returns C<0>.
+
+If the object is C<NULL>, returns C<0>.
+
+=head2 is_numeric_array
+
+  static method is_numeric_array : int ($object : object)
+
+If the object is a numeric array, returns C<1>, otherwise returns C<0>.
+
+If the object is C<NULL>, returns C<0>.
+
+=head2 is_object_array
+
+  static method is_object_array : int ($object : object)
+
+If the object is a object array, returns C<1>, otherwise returns C<0>.
+
+If the object is C<NULL>, returns C<0>.
+
 =head2 join
 
   static method join : string ($sep : string, $strings : string[])
@@ -1107,7 +1131,7 @@ Source offset + length must be within the range of the source array, otherwise a
 
 =head2 new_array_proto
 
-  static method new_array_proto : oarray ($proto_array : oarray, $length : int)
+  static method new_array_proto : object[] ($proto_array : object[], $length : int)
 
 Create a new generic object array as the same type as the given array.
 
@@ -1234,7 +1258,7 @@ Offset + Length must be in the array range. Otherwise an exception occurs.
 
 =head2 sort_object
 
-    static method sort_object : void ($objs : oarray, $offset : int, $length : int, $comparator : Comparator::Object)
+    static method sort_object : void ($objs : object[], $offset : int, $length : int, $comparator : Comparator::Object)
 
 Sort object array itself with a offset, a length, and a L<Comparator::Object|SPVM::Comparator::Object> comparator.
 
